require 'belafonte'
require 'cabal/cli'
require 'cabal/cli/authenticated'
require 'cabal/ssh'

module Cabal
  module CLI
    class SSH < Belafonte::App
      include Authenticated

      title "ssh"
      summary "Connect to a node on a cluster"

      option :cluster_name,
        short: 'c',
        long: 'cluster-name',
        argument: 'CLUSTER_NAME',
        description: 'The name of the cluster to connect'

      option :lifetime,
        short: 'l',
        long: 'lifetime',
        argument: 'MINUTES',
        description: 'How long should we forward SSH identities (default: 30, 0 for no timeout)'

      arg :ssh_signature

      def handle
        with_authentication(partake(:config)) do
          Cabal::SSH.connect(
            cluster: option(:cluster_name),
            ssh_signature: arg(:ssh_signature).first,
            client: partake(:client),
            identity_timeout: lifetime,
            kernel: kernel
          )
        end
      end

      def lifetime
        return nil unless option(:lifetime)
        option(:lifetime).to_i * 60
      end
    end
  end
end
