module Cabal
  # Manages ssh-agent sessions for forwarding identity information via
  # Cabal::SSH
  class IdentityManager

    # @return [String] the environment settings for the running ssh-agent
    attr_reader :env

    # Spawns an ssh-agent process and records its related environment settings
    # @return [nil]
    def start
      @env = start_agent.
        split(/(\;|\n)/).
        select {|line| line =~ /^SSH_/}.
        join(' ')
    end

    # Stops a running ssh-agent that was previously spawned
    # @return [nil]
    def stop
      stop_agent
    end

    private
    def start_agent
      `ssh-agent`
    end

    def stop_agent
      `#{env} ssh-agent -k`
    end
  end
end
